@@ -20,6 +20,7 @@ import numpy as np
 import sys
 import os
 import shutil
+from numba import jit
 
 def wf_scc(tmplt_st,sta_st,ncom):
     """
@@ -53,7 +54,7 @@ def wf_scc(tmplt_st,sta_st,ncom):
     dt = temp[0].stats.delta
     ccmax,aamax,i0,cc_list = data_scc(tmplt_data,st_data,ncom)
 
-
+@jit
 def data_scc(tmplt_data,st_data,ncom):
     """
     Sliding-window cross-correlation between template and target waveform
